@@ -52,6 +52,10 @@ fn main() {
 	if potential_gitignore.exists() {
 		sh.source_ignores(&potential_gitignore).unwrap();
 	}
+	let potential_krileignore = args.source.join(".krileignore");
+	if potential_krileignore.exists() {
+		sh.source_ignores(&potential_krileignore).unwrap();
+	}
 	if !args.ignored_plugins.contains(&"tera_layouts".to_string()) {
 		sh.register(plugins::tera_layouts::plugin());
 	}
